xeus_gp: Jupyter kernel for PARI/GP based on xeus
=================================================

Description
-----------

A Xeus-based Jupyter kernel for PARI/GP


License
-------

GPL 2 or later


Upstream Contact
----------------

- https://pari.math.u-bordeaux.fr/download.html#xeus-gp
- https://pari.math.u-bordeaux.fr/pub/pari/XEUS-GP
- https://pari.math.u-bordeaux.fr/git/xeus-gp.git
- https://github.com/passagemath/upstream-xeus-gp.git
